@@ -168,6 +168,13 @@ class AppBuildCommand(CliCommand):
         for image in images:
             print(f'- {image}')
 
+        for image in images:
+            # Make sure that we correctly tag all images with the docker.io prefix. This is not
+            # guaranteed on alternative runtimes such as podman
+            run_command(['docker', 'tag', image, 'docker.io/' + image], cwd=project_dir)
+            print('retagging...')
+        images = ['docker.io/' + image for image in images]
+
         print('Packaging those images...')
         if os.path.isfile(target_file):
             os.remove(target_file)
